@@ -126,9 +126,9 @@ dDA <- function(x, cll, pool= TRUE)
         if(nk[k] > 1)
             v[,k] <- colVars (lsk, na.rm = TRUE, means = m[,k]) ## else 0
     }
-    structure(list(call = match.call(), cl0 = cl0, n=n, p=p, K=K,
-                   means=m, vars=v, nk=nk, pool=pool),
-              class = "dDA")
+    struct(list(call = match.call(), cl0 = cl0, n=n, p=p, K=K,
+                means=m, vars=v, nk=nk, pool=pool),
+           class = "dDA")
 }
 
 print.dDA <- function(x, ...)
@@ -174,6 +174,13 @@ predict.dDA <- function(object, newdata, pool = object$pool, ...)
     }
     else { ## QDA
         sum.na <- function(x) sum(x, na.rm=TRUE)
+        ## zero - variances are not acceptable later
+	if(any(i0 <- Vr == 0)) {
+	    if(all(i0))
+		stop("all variances are 0 -- cannot predict")
+	    Vr[i0] <- 1e-7 * min(Vr[!i0])
+	}
+
 if(FALSE) { ## not yet quite : fails ../tests/dDA.R  -- FIXME
         for(k in 1:K) {
             y <- newdata - rep(mu[,k], each=nt)
